@@ -35,10 +35,10 @@ extern "C" {
 @class  NSArray;
 @class  NSDate;
 @class  NSDictionary;
-@class  NSLock;
 @class  NSMutableArray;
 @class  NSMutableData;
 @class  NSMutableDictionary;
+@class  NSRecursiveLock;
 @class  NSString;
 @class  NSThread;
 @class  NSTimer;
@@ -128,7 +128,7 @@ extern "C" {
   NSArray		*_prepOrder;
   NSThread		*_queueThread;
   NSThread		*_ioThread;
-  NSLock		*_lock;
+  NSRecursiveLock	*_lock;
   enum {
     RPCIdle = 0,	// Not performing RPC
     RPCQueued,		// In local queue waiting to do I/O or prepare
@@ -338,7 +338,7 @@ extern "C" {
 /** Sets extra headers to be sent as part of any HTTP or HTTPS request
  * initiated by this service.<br />
  * NB. These headers are set *after* the default headers set for content
- * type and user agent etc, so yu can override the values normally set
+ * type and user agent etc, so you can override the values normally set
  * by the service.
  */
 - (void) setHeaders: (NSDictionary*)headers;
